@@ -32,6 +32,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             CONFIGURING = "ConfigurationProgressing"
             SUCCESS = "SuccessfullyConfigured"
             FAILED = "FailedToConfigure"
+            NO_MATCHING_NODE = "NoMatchingNode"
 
     def __init__(
         self,
@@ -301,6 +302,8 @@ class NodeNetworkConfigurationPolicy(Resource):
                 return condition["reason"]
 
     def wait_for_status_success(self):
+        failed_condition_reason = self.Conditions.Reason.FAILED
+        no_match_node_condition_reason = self.Conditions.Reason.NO_MATCHING_NODE
         # if we get here too fast there are no conditions, we need to wait.
         self.wait_for_conditions()
 
@@ -311,7 +314,12 @@ class NodeNetworkConfigurationPolicy(Resource):
                     LOGGER.info("NNCP configured Successfully")
                     return sample
 
-                if sample == self.Conditions.Reason.FAILED:
+                if sample == no_match_node_condition_reason:
+                    raise NNCPConfigurationFailed(
+                        f"Reason: {no_match_node_condition_reason}"
+                    )
+
+                if sample == failed_condition_reason:
                     for failed_nnce in self._get_failed_nnce():
                         nnce_dict = failed_nnce.instance.to_dict()
                         for cond in nnce_dict["status"]["conditions"]:
@@ -323,9 +331,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                                     f"NNCE {nnce_dict['metadata']['name']}: {error[0]}"
                                 )
 
-                    raise NNCPConfigurationFailed(
-                        f"Reason: {self.Conditions.Reason.FAILED}"
-                    )
+                    raise NNCPConfigurationFailed(f"Reason: {failed_condition_reason}")
 
         except (TimeoutExpiredError, NNCPConfigurationFailed):
             LOGGER.error("Unable to configure NNCP for node")
