@@ -10,17 +10,22 @@ class SriovNetwork(NamespacedResource):
 
     def __init__(
         self,
-        name,
-        namespace,
-        network_namespace,
+        name=None,
+        namespace=None,
+        network_namespace=None,
         client=None,
         resource_name=None,
         vlan=None,
         ipam=None,
         teardown=True,
+        yaml_file=None,
     ):
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.network_namespace = network_namespace
         self.resource_name = resource_name
@@ -29,6 +34,9 @@ class SriovNetwork(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         res["spec"] = {
             "ipam": self.ipam or "{}\n",
             "networkNamespace": self.network_namespace,
